aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--resources/libraries/bash/function/per_patch.sh7
1 files changed, 2 insertions, 5 deletions
diff --git a/resources/libraries/bash/function/per_patch.sh b/resources/libraries/bash/function/per_patch.sh
index 61de6f7ade..fc608c46ad 100644
--- a/resources/libraries/bash/function/per_patch.sh
+++ b/resources/libraries/bash/function/per_patch.sh
@@ -66,7 +66,7 @@ function archive_parse_test_results () {
function build_vpp_ubuntu_amd64 () {
# This function is using Vagrant script to build VPP with all dependencies
# that is ARCH/OS aware. VPP repo is SSOT for building mechanics and CSIT
# is consuming artifacts. This way if VPP will introduce change in building
# mechanics they will not be blocked by CSIT repo.
@@ -82,13 +82,10 @@ function build_vpp_ubuntu_amd64 () {
set -exuo pipefail
cd "${VPP_DIR}" || die "Change directory command failed."
- echo 'Building using "make build-root/vagrant/build.sh"'
- build-root/vagrant/"build.sh" || die "Vagrant VPP build script failed."
- echo "*******************************************************************"
+ make pkg-verify || die "VPP build using make pkg-verify failed."
echo "* VPP ${1-} BUILD SUCCESSFULLY COMPLETED" || {
die "Argument not found."
}
- echo "*******************************************************************"
}
@@ -66,7 +66,7 @@ function archive_parse_test_results () {
function build_vpp_ubuntu_amd64 () {
- # This function is using Vagrant script to build VPP with all dependencies
+ # This function is using make pkg-verify to build VPP with all dependencies
# that is ARCH/OS aware. VPP repo is SSOT for building mechanics and CSIT
# is consuming artifacts. This way if VPP will introduce change in building